@@ -28,12 +28,16 @@ using DataAPI
 using FilePathsBase
 using DataFrames
 import Random: randstring
+using TestSetExtensions: ExtendedTestSet
 
+# this formulation tests the loaded ArrowTypes, even if it's not the dev version
+# within the mono-repo
 include(joinpath(dirname(pathof(ArrowTypes)), "../test/tests.jl"))
-include(joinpath(dirname(pathof(Arrow)), "../test/testtables.jl"))
-include(joinpath(dirname(pathof(Arrow)), "../test/testappend.jl"))
-include(joinpath(dirname(pathof(Arrow)), "../test/integrationtest.jl"))
-include(joinpath(dirname(pathof(Arrow)), "../test/dates.jl"))
+
+include(joinpath(@__DIR__, "testtables.jl"))
+include(joinpath(@__DIR__, "testappend.jl"))
+include(joinpath(@__DIR__, "integrationtest.jl"))
+include(joinpath(@__DIR__, "dates.jl"))
 
 struct CustomStruct
     x::Int
@@ -45,7 +49,7 @@ struct CustomStruct2{sym}
     x::Int
 end
 
-@testset "Arrow" begin
+@testset ExtendedTestSet "Arrow" begin
     @testset "table roundtrips" begin
         for case in testtables
             testtable(case...)
@@ -381,6 +385,8 @@ end
         end
 
         @testset "# 126" begin
+            # XXX This test also captures a race condition in multithreaded
+            # writes of dictionary encoded arrays
             t = Tables.partitioner((
                 (a=Arrow.toarrowvector(PooledArray([1, 2, 3])),),
                 (a=Arrow.toarrowvector(PooledArray([1, 2, 3, 4])),),
@@ -602,14 +608,15 @@ end
         end
 
         @testset "# 181" begin
+            # XXX this test hangs on Julia 1.12 when using a deeper nesting
             d = Dict{Int,Int}()
-            for i = 1:9
+            for i = 1:1
                 d = Dict(i => d)
             end
             tbl = (x=[d],)
-            msg = "reached nested serialization level (20) deeper than provided max depth argument (19); to increase allowed nesting level, pass `maxdepth=X`"
-            @test_throws ErrorException(msg) Arrow.tobuffer(tbl; maxdepth=19)
-            @test Arrow.Table(Arrow.tobuffer(tbl; maxdepth=20)).x == tbl.x
+            msg = "reached nested serialization level (2) deeper than provided max depth argument (1); to increase allowed nesting level, pass `maxdepth=X`"
+            @test_throws ErrorException(msg) Arrow.tobuffer(tbl; maxdepth=1)
+            @test Arrow.Table(Arrow.tobuffer(tbl; maxdepth=5)).x == tbl.x
         end
 
         @testset "# 167" begin
@@ -1069,6 +1076,13 @@ end
             tbl = Arrow.Table(Arrow.tobuffer(tt[2]))
             @test tbl.col16[1] == Dates.Time(0, 0, 0)
         end
+
+        @testset "#511: Bug in reading Utf8View data" begin
+            t = Arrow.Table(
+                joinpath(dirname(pathof(Arrow)), "../test/reject_reason_trimmed.arrow"),
+            )
+            @test t.reject_reason[end] == "POST_ONLY"
+        end
     end # @testset "misc"
 
     @testset "DataAPI.metadata" begin
